@@ -134,19 +134,20 @@ merge_files (gint             argc,
   for (guint i = 1; i < argc; i++)
     {
       g_autoptr(SysprofCaptureReader) reader = NULL;
-      g_autoptr(GError) error = NULL;
 
-      if (!(reader = sysprof_capture_reader_new (argv[i], &error)))
+      if (!(reader = sysprof_capture_reader_new (argv[i])))
         {
+          int errsv = errno;
           g_printerr ("Failed to create reader for \"%s\": %s\n",
-                      argv[i], error->message);
+                      argv[i], g_strerror (errsv));
           return EXIT_FAILURE;
         }
 
-      if (!sysprof_capture_writer_cat (writer, reader, &error))
+      if (!sysprof_capture_writer_cat (writer, reader))
         {
+          int errsv = errno;
           g_printerr ("Failed to join \"%s\": %s\n",
-                      argv[i], error->message);
+                      argv[i], g_strerror (errsv));
           return EXIT_FAILURE;
         }
     }
@@ -203,6 +204,7 @@ main (gint   argc,
   gboolean no_memory = FALSE;
   gboolean no_network = FALSE;
   gboolean no_perf = FALSE;
+  gboolean no_throttle = FALSE;
   gboolean version = FALSE;
   gboolean force = FALSE;
   gboolean use_trace_fd = FALSE;
@@ -210,10 +212,12 @@ main (gint   argc,
   gboolean rapl = FALSE;
   gboolean memprof = FALSE;
   gboolean merge = FALSE;
+  gboolean speedtrack = FALSE;
   int pid = -1;
   int fd;
   int flags;
   GOptionEntry entries[] = {
+    { "no-throttle", 0, 0, G_OPTION_ARG_NONE, &no_throttle, N_("Disable CPU throttling while profiling") },
     { "pid", 'p', 0, G_OPTION_ARG_INT, &pid, N_("Make sysprof specific to a task"), N_("PID") },
     { "command", 'c', 0, G_OPTION_ARG_STRING, &command, N_("Run a command and profile the process"), N_("COMMAND") },
     { "env", 'e', 0, G_OPTION_ARG_STRING_ARRAY, &envs, N_("Set environment variable for spawned process. Can be used multiple times."), N_("VAR=VALUE") },
@@ -231,6 +235,7 @@ main (gint   argc,
     { "rapl", 0, 0, G_OPTION_ARG_NONE, &rapl, N_("Include RAPL energy statistics") },
     { "memprof", 0, 0, G_OPTION_ARG_NONE, &memprof, N_("Profile memory allocations and frees") },
     { "gnome-shell", 0, 0, G_OPTION_ARG_NONE, &gnome_shell, N_("Connect to org.gnome.Shell for profiler statistics") },
+    { "speedtrack", 0, 0, G_OPTION_ARG_NONE, &speedtrack, N_("Track performance of the applications main loop") },
     { "merge", 0, 0, G_OPTION_ARG_NONE, &merge, N_("Merge all provided *.syscap files and write to stdout") },
     { "version", 0, 0, G_OPTION_ARG_NONE, &version, N_("Print the sysprof-cli version and exit") },
     { NULL }
@@ -502,6 +507,14 @@ Examples:\n\
       g_object_unref (source);
     }
 
+  if (no_throttle)
+    {
+      source = sysprof_governor_source_new ();
+      sysprof_governor_source_set_disable_governor (SYSPROF_GOVERNOR_SOURCE (source), TRUE);
+      sysprof_profiler_add_source (profiler, source);
+      g_object_unref (source);
+    }
+
   if (gnome_shell)
     {
       source = sysprof_proxy_source_new (G_BUS_TYPE_SESSION,
@@ -518,6 +531,15 @@ Examples:\n\
       g_object_unref (source);
     }
 
+  if (speedtrack)
+    {
+      source = g_object_new (SYSPROF_TYPE_PRELOAD_SOURCE,
+                             "preload", "libsysprof-speedtrack-3.so",
+                             NULL);
+      sysprof_profiler_add_source (profiler, source);
+      g_object_unref (source);
+    }
+
   if (pid != -1)
     {
       sysprof_profiler_set_whole_system (profiler, FALSE);
